@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-use version; our $VERSION = 'v0.6.4';
+use version; our $VERSION = 'v0.7.0';
 
 our @COMMANDS_INFO = (
     +{
@@ -167,6 +167,16 @@ Usage:
     > cas mykey1 MyValue1 1
     > cas mykey2 MyValue2 26  0     # Never expires. Default
     > cas mykey3 MyValue3 355 120 1
+EODESC
+    },
+    +{
+        command => 'touch',
+        summary => 'Update data with new EXPIRE',
+        description => <<'EODESC',
+Usage:
+    > touch <KEY> <EXPIRE>
+    > touch foo 300  # will expire in 5 min
+    > touch bar 0    # will never expire
 EODESC
     },
     +{
