@@ -17,7 +17,7 @@ use App::Memcached::CLI::Help;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.6.4';
+use version; our $VERSION = 'v0.7.0';
 
 my $PROGRAM = basename $0;
 
@@ -39,6 +39,7 @@ my %COMMAND2ALIASES = (
     append     => [],
     prepend    => [],
     cas        => [],
+    touch      => [],
     delete     => [],
     flush_all  => [qw(flush)],
 );
@@ -300,6 +301,22 @@ sub cas {
     return 1;
 }
 
+sub touch {
+    my $self   = shift;
+    my $key    = shift;
+    my $expire = shift;
+    unless ($key and defined $expire) {
+        print "No KEY or EXPIRE specified.\n";
+        return;
+    }
+    unless ($self->{ds}->touch($key, $expire)) {
+        print "Failed to touch. KEY $key maybe missing\n";
+        return;
+    }
+    print "OK\n";
+    return 1;
+}
+
 sub delete {
     my $self = shift;
     my $key  = shift;
